# Cost Management
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/cost-management#overview)
  * [Project Cost](https://help.sap.com/docs/leanix/ea/cost-management#project-cost)
  * [Application Cost](https://help.sap.com/docs/leanix/ea/cost-management#application-cost)
  * [Infrastructure Cost](https://help.sap.com/docs/leanix/ea/cost-management#infrastructure-cost)
  * [Collect and Update Cost Data](https://help.sap.com/docs/leanix/ea/cost-management#collect-and-update-cost-data)
  * [Advanced Cost Management with Customized Configurations](https://help.sap.com/docs/leanix/ea/cost-management#advanced-cost-management-with-customized-configurations)
  * [Additional Information](https://help.sap.com/docs/leanix/ea/cost-management#additional-information)


Track and analyze IT costs across projects, applications, and infrastructure. Support strategic financial decisions in enterprise architecture with the right insights from reports.
